"olsfit" <-
  function (vario, ini, cov.model = c("exponential", "matern", 
                          "gaussian", "spherical", "circular", "cubic", "wave", "powered.exponential", "cauchy", 
                          "gneiting", "gneiting.matern", "pure.nugget"), kappa = NULL, simul.number = NULL, 
            max.dist = "all", minimisation.function = "nlm", lower = 0, fix.nugget = FALSE, 
            nugget = 0, messages.screen=TRUE, ...) 
{
  call.fc <- match.call()
  if (minimisation.function != "nlm" & minimisation.function != "nls") 
    stop("minimization functions available are: nlm or nls")
  if (is.matrix(vario$v) & is.null(simul.number)) 
    stop("object in vario$v is a matrix. This function works for only 1 empirical variogram")
  if (!is.null(simul.number)) 
    vario$v <- vario$v[, simul.number]
  if(is.matrix(ini)) {
    inilength <- dim(ini)[2]
    if(fix.nugget == FALSE & inilength != 3)
      stop("wrong number of columns for ini (must be 3)")
    if(fix.nugget == TRUE & inilength != 2)
      stop("wrong number of columns for ini (must be 2)")
  }
  else {
    inilength <- length(ini)
    if (fix.nugget == FALSE & inilength != 3) 
      stop("wrong length for ini (must be 3)")
    if (fix.nugget == TRUE & inilength != 2) 
      stop("wrong length for ini (must be 2)")
  }
  cov.model <- match.arg(cov.model)
  if (max.dist == "all") 
    data <- data.frame(u = vario$u, v = vario$v)
  else data <- data.frame(u = vario$u[vario$u <= max.dist], v = vario$v[vario$u <= max.dist])
  data$kappa <- kappa
  data$cov.model <- cov.model
  if (minimisation.function == "nls") {
    require(nls)
    if (fix.nugget == FALSE) {
      result <- nls(v ~ ((sigmasq + tausq) - cov.spatial(u, 
                                                         cov.model = cov.model, kappa = kappa, cov.pars = c(sigmasq, 
                                                                                                 phi))), start = list(tausq = ini[1], sigmasq = ini[2], 
                                                                                                           phi = ini[3]), data = data)
      nugget <- result$parameter[1]
      cov.pars <- as.vector(result$parameter[2:3])
      value <- vario$v - ((nugget + cov.pars[1]) - cov.spatial(vario$u, 
                                                               cov.model = cov.model, kappa = kappa, cov.pars = cov.pars))
    }
    else {
      data$nugget <- nugget
      result <- nls(v ~ ((sigmasq + ftau) - cov.spatial(u, 
                                                        cov.model = cov.model, kappa = kappa, cov.pars = c(sigmasq, 
                                                                                                phi))), start = list(sigmasq = ini[1], phi = ini[2]), 
                    data = data)
      cov.pars <- as.vector(result$parameter[1:2])
      value <- vario$v - ((nugget + cov.pars[1]) - cov.spatial(vario$u, 
                                                               cov.model = cov.model, kappa = kappa, cov.pars = cov.pars))
    }
    value <- sum(value * value)
    message <- "nls does not provides convergence message"
  }
  if (minimisation.function == "nlm") {
    .global.list <<- list(data = data, fix.nugget = fix.nugget, nugget = nugget, 
                          kappa = kappa, cov.model = cov.model)
    .global.lower <<- lower
    if(is.matrix(ini) | is.data.frame(ini)) {
      ini <- as.matrix(ini)
      cat("olsfit: searching for the best initial value\n")
      ini.search <- ini
      dimnames(ini.search) <- list(NULL, NULL)
      ols.ini <- round(100000000. * apply(ini.search, 1, 
                                          loss.olsvario))
      ini <- as.vector(ini.search[ols.ini == min(ols.ini),
                                      ])
      cat("olsfit: best initial value:\n")
      if(fix.nugget == TRUE){
        names(ini) <- c("sill", "range")
        print(ini)
      }
      else{
        names(ini) <- c("nugget", "sill", "range")
        print(ini)
      }
    }
    result <- nlm(loss.olsvario, ini, ...)	   
    if (exists(".temp.theta", w=1)){
      result$estimate <- .temp.theta
      remove(".temp.theta", pos=1, inherits = TRUE)
    }
    rm(.global.list, .global.lower, inherits = TRUE)
    value <- result$minimum
    message <- paste("Exit code:", result$code)
    if (fix.nugget == FALSE) {
      nugget <- result$estimate[1]
      cov.pars <- as.vector(result$estimate[2:3])
    }
    else {
      cov.pars <- as.vector(result$estimate[1:2])
    }
  }
  dmax <- max(vario$u)
  estimation <- list(nugget = nugget, cov.pars = cov.pars, 
                     cov.model = cov.model, kappa = kappa, value = value, 
                     max.dist = dmax, minimisation.function = minimisation.function, message = message)
  estimation$method <- "OLS"
  estimation$call <- call.fc
  class(estimation) <- "variomodel"
  if(messages.screen){
    cat("olsfit: estimated model parameters are:\n")
    cat(paste("covariance model:", cov.model))
    if(cov.model == "matern" | cov.model == "powered.exponential" | 
       cov.model == "cauchy" | cov.model == "gneiting.matern")
      cat(paste(" with kappa =", kappa))
    if(!is.null(kappa))
      if(cov.model == "matern" & kappa == 0.5)
        cat(" (exponential)")
    cat("\n")
    print(c(nugget=estimation$nugget, sill=estimation$cov.pars[1], range=estimation$cov.pars[2]))
  }
  return(estimation)
}


"wlsfit" <-
function (vario, ini, cov.model = c("exponential", "matern", 
    "gaussian", "spherical", "circular", "cubic", "wave", "powered.exponential", "cauchy", 
    "gneiting", "gneiting.matern", "pure.nugget"), kappa = NULL, simul.number = NULL, 
    max.dist = "all", minimisation.function = "nlm", lower = 0, fix.nugget = FALSE, 
    nugget = 0, weight = c("npairs", "cressie"), messages.screen=TRUE, ...) 
{
  call.fc <- match.call()
  weight <- match.arg(weight)
  if (minimisation.function != "nlm") 
    stop("minimization function available is: nlm")
  if (is.matrix(vario$v) & is.null(simul.number)) 
    stop("object in vario$v is a matrix. This function works for only 1 empirical variogram")
  if (!is.null(simul.number)) 
    vario$v <- vario$v[, simul.number]
  if(is.matrix(ini)) {
    inilength <- dim(ini)[2]
    if(fix.nugget == FALSE & inilength != 3)
      stop("wrong number of columns for ini (must be 3)")
    if(fix.nugget == TRUE & inilength != 2)
      stop("wrong number of columns for ini (must be 2)")
  }
  else {
    inilength <- length(ini)
    if (fix.nugget == FALSE & inilength != 3) 
      stop("wrong length for ini (must be 3)")
    if (fix.nugget == TRUE & inilength != 2) 
      stop("wrong length for ini (must be 2)")
  }
  cov.model <- match.arg(cov.model)
  if (max.dist == "all") 
    data <- list(u = vario$u, v = vario$v, n = vario$n)
  else data <- list(u = vario$u[vario$u <= max.dist], v = vario$v[vario$u <= 
                                                        max.dist], n = vario$n[vario$u <= max.dist])
  holdit <- data$v
  holdit[is.na(holdit)] <- 0
  data$v <- holdit
  data$kappa <- kappa
  data$cov.model <- cov.model
  .global.list <<- list(data = data, fix.nugget = fix.nugget,
                        nugget = nugget, 
                        kappa = kappa, cov.model = cov.model,
                        weight = weight)
  .global.lower <<- lower
  if(is.matrix(ini) | is.data.frame(ini)) {
    ini <- as.matrix(ini)
    cat("wlsfit: searching for the best initial value\n")
    ini.search <- ini
    dimnames(ini.search) <- list(NULL, NULL)
    wls.ini <- round(100000000. * apply(ini.search, 1, loss.wlsvario))
    ini <- as.vector(ini.search[wls.ini == min(wls.ini),])
    cat("wlsfit: best initial value:\n")
    if(fix.nugget == TRUE){
      names(ini) <- c("sill", "range")
      print(ini)
    }
    else{
      names(ini) <- c("nugget", "sill", "range")
      print(ini)
    }
  }
  result <- nlm(loss.wlsvario, ini, ...)
  if (exists(".temp.theta", w=1)){
    result$estimate <- .temp.theta
    remove(".temp.theta", pos=1, inherits = TRUE)
  }
  rm(.global.list, .global.lower, inherits = TRUE)
  value <- result$minimum
  message <- paste("Exit code:", result$code)
  if (fix.nugget == FALSE) {
    nugget <- result$estimate[1]
    cov.pars <- as.vector(result$estimate[2:3])
  }
  else {
    cov.pars <- as.vector(result$estimate[1:2])
  }
  estimation <- list(nugget = nugget, cov.pars = cov.pars, 
                     cov.model = cov.model, kappa = kappa, value = value, 
                     max.dist = max(data$u), minimisation.function = minimisation.function, message = message)
  estimation$method <- "WLS"
  estimation$call <- call.fc
  class(estimation) <- "variomodel"
  if(messages.screen){
    cat("wlsfit: estimated model parameters are:\n")
    cat(paste("covariance model:", cov.model))
    if(cov.model == "matern" | cov.model == "powered.exponential" | 
       cov.model == "cauchy" | cov.model == "gneiting.matern")
      cat(paste(" with kappa =", kappa))
    if(!is.null(kappa))
      if(cov.model == "matern" & kappa == 0.5)
        cat(" (exponential)")
    cat("\n")
    print(c(nugget=estimation$nugget, sill=estimation$cov.pars[1], range=estimation$cov.pars[2]))
  }
  return(estimation)
}


"loss.olsvario" <-
function (theta) 
{
  if (exists(".temp.theta", w=1)) remove(".temp.theta", pos=1, inherits = TRUE)
  theta.minimiser <- theta
  penalty <- 10000 * sum(.global.lower - pmin(theta, .global.lower))
  theta <- pmax(theta, .global.lower)
  if (any(theta.minimiser < .global.lower))
    assign(".temp.theta", theta, pos=1)
  u <- .global.list$data$u
  v <- .global.list$data$v
  kappa <- .global.list$kappa
  if (.global.list$fix.nugget == FALSE) {
    tausq <- theta[1]
    sigmasq <- theta[2]
    phi <- theta[3]
    tau1 <- tausq
  }
  else {
    tausq <- .global.list$nugget
    sigmasq <- theta[1]
    phi <- theta[2]
    tau1 <- tausq + 1
  }
  sill.total <- sigmasq + tausq
  if (.global.list$fix.nugget == FALSE) {
    gamma <- sill.total - cov.spatial(u, cov.model = .global.list$cov.model, 
                                    kappa = kappa, cov.pars = c(theta[2], theta[3]))
  }
  else {
    gamma <- sill.total - cov.spatial(u, cov.model = .global.list$cov.model, 
                                    kappa = kappa, cov.pars = c(theta[1], theta[2]))
  }
  loss <- sum((v - gamma)^2)
  return(loss + penalty)
}

"loss.wlsvario" <-
function (theta) 
{
  if (exists(".temp.theta", w=1)) remove(".temp.theta", pos=1, inherits = TRUE)
  theta.minimiser <- theta
  penalty <- 10000 * sum(.global.lower - pmin(theta, .global.lower))
  theta <- pmax(theta, .global.lower)
  if (any(theta.minimiser < .global.lower))
    assign(".temp.theta", theta, pos=1)
  u <- .global.list$data$u
  v <- .global.list$data$v
  n <- .global.list$data$n
  kappa <- .global.list$kappa
  if (.global.list$fix.nugget == FALSE) {
    tausq <- theta[1]
    sigmasq <- theta[2]
    phi <- theta[3]
    tau1 <- tausq
  }
  else {
    tausq <- .global.list$nugget
    sigmasq <- theta[1]
    phi <- theta[2]
    tau1 <- tausq + 1
  }
  sill.total <- sigmasq + tausq
  if (.global.list$fix.nugget == FALSE) {
    gamma <- sill.total - cov.spatial(u, cov.model = .global.list$cov.model, 
                                    kappa = kappa, cov.pars = c(theta[2], theta[3]))
  }
  else {
    gamma <- sill.total - cov.spatial(u, cov.model = .global.list$cov.model, 
                                    kappa = kappa, cov.pars = c(theta[1], theta[2]))
  }
  if (.global.list$weight == "npairs") 
    loss <- sum(n * (v - gamma)^2)
  if (.global.list$weight == "cressie") 
    loss <- sum((n/(gamma^2)) * (v - gamma)^2)
  return(loss + penalty)
}
