\name{as.geodata}
\alias{as.geodata}

%- Also NEED an `\alias' for EACH other topic documented here.
\title{Converts an Object to the Class "geodata"}

\description{
  Converts a matrix or a data-frame to an object of the
  \code{\link{class}}  \code{"geodata"}.
  An object of the class \code{"geodata"} is a list with two obligatory
  components, \code{coords} and \code{data} and an optional component
  typically with values of the covariate(s).
}

\usage{
as.geodata(obj, coords.col = 1:2, data.col = 3, data.names = NULL, 
           covar.col = NULL, covar.names = "obj.names")
}

%- maybe also `usage' for other objects documented here.

\arguments{
  \item{obj}{a matrix or data-frame. The lines must have
    coordinates, data values and (optionally) covariates for
    each of the data locations.  }
  \item{coords.col}{a vector with the numbers of the columns containing the
    coordinates.  }
  \item{data.col}{a scalar or vector with the number of the column(s)
    containing the data.  }
  \item{data.names}{a string or vector of strings with names for
    the data columns. Only valid if there is more than one column of
    data.
    By default the names in the original object are used.  }
  \item{covar.col}{optional. A scalar or vector with the number
    of the column(s) with the values of the covariate(s).  }
  \item{covar.names}{a string or vector of strings with the name(s) of
    the covariates. By default the names in the original object are used.  }
}

\details{
  Objects of the class \code{"geodata"} contain data for
  geostatistical analysis using the package \bold{geoR}.
  Storing data in this format facilitates the usage of the functions in \bold{geoR}.
  However this is not is not obligatory to carry out the analysis.
  
  The component \code{coords} is always an \eqn{n \times 2}  matrix where
  \eqn{n} is the number of data points.\cr
  The component \code{data} can be a vector, for the univariate case or,
  a matrix or data-frame for the multivariate case.\cr
  The third component is optional, does not have a fixed name,
  and contains the values of the covariate(s).
  
}

\value{
  An object of the \code{\link{class}} \code{"geodata"} which is a list
  with two obligatory components:
  \item{coords}{data coordinates}
  \item{data}{data values}

  \item and an optional one:

  \item{covariate}{covariates values}

}

\references{
  Further information about \bold{geoR/geoS} can be found at:\cr
  \url{http://www.maths.lancs.ac.uk/~ribeiro/geoR.html}
}

\author{
  Paulo Justiniano Ribeiro Jr. \email{paulojus@est.ufpr.br} \cr
  Peter J. Diggle \email{p.diggle@lancaster.ac.uk}.
}

%\note{ ~~further notes~~ }
%
% ~Make other sections like WARNING with \section{WARNING }{....} ~

\seealso{\code{\link{read.geodata}} for reading data from an
  \emph{ASCII} file and \code{\link{list}} for information about lists
  in \R.
}

%\examples{}
\keyword{spatial, class, manip}%-- one or more ...


